/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 1991-2007 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Class
    ASMSSG

Description
    Standard k-epsilon turbulence model.

SourceFiles
    ASMSSG.C
    ASMSSGCorrect.C

\*---------------------------------------------------------------------------*/

#ifndef ASMSSG_H
#define ASMSSG_H

#include "turbulenceModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace turbulenceModels
{

/*---------------------------------------------------------------------------*\
                           Class ASMSSG Declaration
\*---------------------------------------------------------------------------*/

class ASMSSG
:
    public turbulenceModel
{
    
    // Private data
      
        dimensionedScalar Cmu;
        dimensionedScalar C1;
        dimensionedScalar C2;
        dimensionedScalar alphaEps;
dimensionedScalar fr;

 volSymmTensorField R_;               
              
volScalarField k_;
        volScalarField epsilon_;
        volScalarField nut_;


//87135-1997,agahiestekhdam@yahoo.com


public:


    //- Runtime type information
    TypeName("ASMSSG");

    // Constructors

        //- Construct from components
        ASMSSG
        (
            const volVectorField& U,
            const surfaceScalarField& phi,
            transportModel& transport
        );


    // Destructor

        ~ASMSSG()
        {}


    // Member Functions

        tmp<volScalarField> nut() const
        {
            return nut_;
        }
/*tmp<volScalarField> nuEff() const
        {
            return tmp<volScalarField>(new volScalarField("nuEff",nut_+nu()));
        }
*/
        //- Return the effective diffusivity for k
        tmp<volScalarField> DkEff() const
        {
            return tmp<volScalarField> 
            (
                new volScalarField("DkEff", nut_ + nu())
            );
        }

        //- Return the effective diffusivity for epsilon
        tmp<volScalarField> DepsilonEff() const
        {
            return tmp<volScalarField> 
            (
                new volScalarField("DepsilonEff", alphaEps*nut_ + nu())
            );
        }

        tmp<volScalarField> k() const
        {
            return k_;
        }


        tmp<volScalarField> epsilon() const
        {
            return epsilon_;
        }


/*tmp<volSymmTensorField> Rssg_() const 
{
return Rssg;
}
*/


   
          tmp<volSymmTensorField> R() const
        {
            return R_;
        }

        tmp<fvVectorMatrix> divR(volVectorField& U) const;

        
        void correct();

        //- Read turbulenceProperties dictionary
        bool read();
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace turbulenceModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
